@@ -5,7 +5,7 @@
 #          config values from a given file and
 #          return it as hash structure
 #
-# Copyright (c) 2000-2016 Thomas Linden <tlinden |AT| cpan.org>.
+# Copyright (c) 2000-2022 Thomas Linden <tlinden |AT| cpan.org>.
 # All Rights Reserved. Std. disclaimer applies.
 # Artistic License, same as perl itself. Have fun.
 #
@@ -32,7 +32,7 @@ use Carp::Heavy;
 use Carp;
 use Exporter;
 
-$Config::General::VERSION = "2.62";
+$Config::General::VERSION = "2.64";
 
 use vars  qw(@ISA @EXPORT_OK);
 use base qw(Exporter);
@@ -339,7 +339,8 @@ sub _prepare {
 
   if (exists $conf{-DefaultConfig}) {
     if ($conf{-DefaultConfig} && ref($conf{-DefaultConfig}) eq 'HASH') {
-      $self->{DefaultConfig} = $conf{-DefaultConfig};
+      # copy the hashref so that it is not being modified by subsequent calls, fixes bug#142095
+      $self->{DefaultConfig} = $self->_copy($conf{-DefaultConfig});
     }
     elsif ($conf{-DefaultConfig} && ref($conf{-DefaultConfig}) eq q()) {
       $self->_read($conf{-DefaultConfig}, 'SCALAR');
@@ -454,9 +455,18 @@ sub _open {
     $configfile = $basefile;
   }
 
-  if ($this->{IncludeGlob} and $configfile =~ /[*?\[\{\\]/) {
+  my $glob = qr/[*?\[\{\\]/;
+  if ($^O =~ /win/i) {
+    # fix for rt.cpan.org#116340: do only consider a backslash
+    # as meta escape char, but not if it appears on it's own,
+    # as it happens on windows platforms.
+    $glob = qr/(\\[*?\[\{\\]|[*?\[\{])/;
+  }
+
+  if ($this->{IncludeGlob} and $configfile =~ /$glob/) {
     # Something like: *.conf (or maybe dir/*.conf) was included; expand it and
     # pass each expansion through this method again.
+    local $_;
     my @include = grep { -f $_ } bsd_glob($configfile, GLOB_BRACE | GLOB_QUOTE);
 
     # applied patch by AlexK fixing rt.cpan.org#41030
@@ -473,8 +483,8 @@ sub _open {
     # Multiple results or no expansion results (which is fine,
     # include foo/* shouldn't fail if there isn't anything matching)
     # rt.cpan.org#79869: local $this->{IncludeGlob};
-    for (@include) {
-      $this->_open($_);
+    foreach my $file (@include) {
+      $this->_open($file);
     }
     return;
   }
@@ -2836,7 +2846,7 @@ I recommend you to read the following documents, which are supplied with Perl:
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2000-2016 Thomas Linden
+Copyright (c) 2000-2022 Thomas Linden
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -2865,7 +2875,7 @@ Thomas Linden <tlinden |AT| cpan.org>
 
 =head1 VERSION
 
-2.62
+2.64
 
 =cut
 
